        #region Data Transfer Instructions
        ;The data transfer instructions move data between memory and the general-purpose and segment registers. They
        ;also perform specific operations such as conditional moves, stack access, and data conversion.

        ; <summary>Move data between general-purpose registers; move data between memory and general purpose or segment registers; move immediates to general-purpose registers</summary>
        MOV,
        ; <summary>Conditional move if equal (ZF=1) (CMOVE=CMOVZ)</summary>
        CMOVE,
        ; <summary>Conditional move if zero (ZF=1) (CMOVE=CMOVZ)</summary>
        CMOVZ,
        ; <summary>Conditional move if not equal (ZF=0) (CMOVNE=CMOVNZ)</summary>
        CMOVNE,
        ; <summary>Conditional move if not zero (ZF=0) (CMOVNE=CMOVNZ)</summary>
        CMOVNZ,
        ; <summary>Conditional move if above (CF=0 and ZF=0) (CMOVA=CMOVNBE)</summary>
        CMOVA,
        ; <summary>Conditional move if not below or equal (CF=0 and ZF=0) (CMOVA=CMOVNBE)</summary>
        CMOVNBE,
        ; <summary>Conditional move if above or equal (CF=0) (CMOVAE=CMOVNB=CMOVNC)</summary>
        CMOVAE,
        ; <summary>Conditional move if not below (CF=0) (CMOVAE=CMOVNB=CMOVNC)</summary>
        CMOVNB,
        ; <summary>Conditional move if below (CF=1) (CMOVB=CMOVC=CMOVNAE)</summary>
        CMOVB,
        ; <summary>Conditional move if not above or equal (CF=1) (CMOVB=CMOVC=CMOVNAE)</summary>
        CMOVNAE,
        ; <summary>Conditional move if below or equal (CF=1 or ZF=1) (CMOVBE=CMOVNA)</summary>
        CMOVBE,
        ; <summary>Conditional move if not above (CF=1 or ZF=1) (CMOVBE=CMOVNA)</summary>
        CMOVNA,
        ; <summary>Conditional move if greater (ZF=0 or SF=OF) (CMOVG=CMOVNLE)</summary>
        CMOVG,
        ; <summary>Conditional move if not less or equal (ZF=0 and SF=OF) (CMOVG=CMOVNLE)</summary>
        CMOVNLE,
        ; <summary>Conditional move if greater or equal (SF=OF) (CMOVGE=CMOVNL)</summary>
        CMOVGE,
        ; <summary>Conditional move if not less (SF=OF) (CMOVGE=CMOVNL)</summary>
        CMOVNL,
        ; <summary>Conditional move if less (SF!=OF) (CMOVL=CMOVNGE)</summary>
        CMOVL,
        ; <summary>Conditional move if not greater or equal (SF!=OF) (CMOVL=CMOVNGE)</summary>
        CMOVNGE,
        ; <summary>Conditional move if less or equal (ZF=1 or SF!=OF) (CMOVLE=CMOVNG)</summary>
        CMOVLE,
        ; <summary>Conditional move if not greater (ZF=1 or SF!=OF) (CMOVLE=CMOVNG)</summary>
        CMOVNG,
        ; <summary>Conditional move if carry (CF=1) (CMOVB=CMOVC=CMOVNAE)</summary>
        CMOVC,
        ; <summary>Conditional move if not carry (CF=0) (CMOVAE=CMOVNB=CMOVNC)</summary>
        CMOVNC,
        ; <summary>Conditional move if overflow (OF=1)</summary>
        CMOVO,
        ; <summary>Conditional move if not overflow (OF=0)</summary>
        CMOVNO,
        ; <summary>Conditional move if sign(negative) (SF=1)</summary>
        CMOVS,
        ; <summary>Conditional move if not sign(non-negative) (SF=0)</summary>
        CMOVNS,
        ; <summary>Conditional move if parity (PF=1) (CMOVP=CMOVPE)</summary>
        CMOVP,
        ; <summary>Conditional move if parity even (PF=1) (CMOVP=CMOVPE)</summary>
        CMOVPE,
        ; <summary>Conditional move if not parity (PF=0) (CMOVNP=CMOVPO)</summary>
        CMOVNP,
        ; <summary>Conditional move if parity odd (PF=0) (CMOVNP=CMOVPO)</summary>
        CMOVPO,
        ; <summary>Exchange</summary>
        XCHG,
        ; <summary>Byte swap</summary>
        BSWAP,
        ; <summary>Exchange and add</summary>
        XADD,
        ; <summary>Compare and exchange</summary>
        CMPXCHG,
        ; <summary>Compare and exchange 8 bytes</summary>
        CMPXCHG8B,
        ; <summary> Push onto stack</summary>
        PUSH,
        ; <summary>Pop off of stack</summary>
        POP,
        ; <summary>Push general-purpose registers onto stack</summary>
        PUSHA,
        ; <summary>Push general-purpose registers onto stack</summary>
        PUSHAD,
        ; <summary> Pop general-purpose registers from stack</summary>
        POPA,
        ; <summary> Pop general-purpose registers from stack</summary>
        POPAD,
        ; <summary>Convert word to doubleword</summary>
        CWD,
        ; <summary>Convert doubleword to quadword</summary>
        CDQ,
        ; <summary>Convert byte to word</summary>
        CBW,
        ; <summary>Convert word to doubleword in EAX register</summary>
        CWDE,
        ; <summary>Move and sign extend</summary>
        MOVSX,
        ; <summary>Move and sign extend</summary>
        MOVSXD,
        ; <summary>Move and zero extend</summary>
        MOVZX,
        ; <summary>Move and zero extend</summary>
        ;MOVZXD, TODO: does this instruction realy exists? if it does it does it implements just a mov
        #endregion
        #region Binary Arithmetic Instructions
        ; The binary arithmetic instructions perform basic binary integer computations on byte, word, and doubleword integers
        ; located in memory and/or the general purpose registers.
        ; <summary>Unsigned integer add with carry</summary>
        ADCX,
        ; <summary>Unsigned integer add with overflow</summary>
        ADOX,
        ; <summary>Integer add</summary>
        ADD,
        ; <summary>Add with carry</summary>
        ADC,
        ; <summary>Subtract</summary>
        SUB,
        ; <summary>Subtract with borrow</summary>
        SBB,
        ; <summary>Signed multiply</summary>
        IMUL,
        ; <summary>Unsigned multiply</summary>
        MUL,
        ; <summary>Signed divide</summary>
        IDIV,
        ; <summary>Unsigned divide</summary>
        DIV,
        ; <summary>Increment</summary>
        INC,
        ; <summary>Decrement</summary>
        DEC,
        ; <summary>Negate</summary>
        NEG,
        ; <summary>Compare</summary>
        CMP,
        #endregion
        #region Decimal Arithmetic Instructions
        ;The decimal arithmetic instructions perform decimal arithmetic on binary coded decimal (BCD) data.

        
        DAA,; Decimal adjust after addition
        
        DAS,; Decimal adjust after subtraction
        
        AAA,; ASCII adjust after addition
        
        AAS,; ASCII adjust after subtraction
        
        AAM,; ASCII adjust after multiplication
        
        AAD,; ASCII adjust before division
        #endregion
        #region Logical Instructions
        ;The logical instructions perform basic AND, OR, XOR, and NOT logical operations on byte, word, and doubleword
        ;values.
        
        AND,; Perform bitwise logical AND
        
        OR,; Perform bitwise logical OR
        
        XOR,; Perform bitwise logical exclusive OR
        
        NOT,; Perform bitwise logical NOT
        #endregion
        #region Shift and Rotate Instructions
        ;The shift and rotate instructions shift and rotate the bits in word and doubleword operands.
        ; <summary>Shift arithmetic right</summary>
        SAR,
        ; <summary>Shift logical right</summary>
        SHR,
        ; <summary>Shift arithmetic left</summary>
        SAL,
        ; <summary>Shift logical left</summary>
        SHL,
        ; <summary> Shift right double</summary>
        SHRD,
        ; <summary>/Shift left double</summary>
        SHLD,
        ; <summary>Rotate right</summary>
        ROR,
        ; <summary> Rotate left</summary>
        ROL,
        ; <summary> Rotate through carry right</summary>
        RCR,
        ; <summary>Rotate through carry left</summary>
        RCL,
        #endregion
        #region Bit and Byte Instructions
        ;Bit instructions test and modify individual bits in word and doubleword operands. Byte instructions set the value of
        ;a byte operand to indicate the status of flags in the EFLAGS register.
        ; <summary>Bit test</summary>
        BT,
        ; <summary>Bit test and set</summary>
        BTS,
        ; <summary>Bit test and reset</summary>
        BTR,
        ; <summary>Bit test and complement</summary>
        BTC,
        ; <summary>Bit scan forward</summary>
        BSF,
        ; <summary>Bit scan reverse</summary>
        BSR,
        ; <summary>Set byte if equal (ZF=1) (SETE=ZETZ)</summary>
        SETE,
        ; <summary>Set byte if zero (ZF=1) (SETE=ZETZ)</summary>
        SETZ,
        ; <summary>Set byte if not equal (ZF=0) (SETNE=SETNZ)</summary>
        SETNE,
        ; <summary>Set byte if not zero (ZF=0) (SETNE=SETNZ)</summary>
        SETNZ,
        ; <summary>Set byte if above (CF=0 and ZF=0) (SETA=SETNBE)</summary>
        SETA,
        ; <summary>Set byte if not below or equal (CF=0 and ZF=0) (SETA=SETNBE)</summary>
        SETNBE,
        ; <summary>Set byte if above or equal (CF=0) (SETAE=SETNC=SETNB)</summary>
        SETAE,
        ; <summary>Set byte if not below (CF=0) (SETAE=SETNC=SETNB)</summary>
        SETNB,
        ; <summary>Set byte if not carry (CF=0) (SETAE=SETNC=SETNB)</summary>
        SETNC,
        ; <summary>Set byte if below (CF=1) (SETB=SETC=SETNAE)</summary>
        SETB,
        ; <summary>Set byte if not above or equal (CF=1) (SETB=SETC=SETNAE)</summary>
        SETNAE,
        ; <summary>Set byte if carry (CF=1) (SETB=SETC=SETNAE)</summary>
        SETC,
        ; <summary>Set byte if below or equal (CF=1 or ZF=1) (SETBE=SETNA)</summary>
        SETBE,
        ; <summary>Set byte if not above (CF=1 or ZF=1) (SETBE=SETNA)</summary>
        SETNA,
        ; <summary>Set byte if greater (ZF=0 and SF=OF) (SETG=SETNLE)</summary>
        SETG,
        ; <summary>Set byte if not less or equal (ZF=0 and SF=OF) (SETG=SETNLE)summary>
        SETNLE,
        ; <summary>Set byte if greater or equal (SF=OF) (SETGE=SETNL)</summary>
        SETGE,
        ; <summary>Set byte if not less (SF=OF) (SETGE=SETNL)(</summary>
        SETNL,
        ; <summary>Set byte if less (SF!=OF) (SETL=SETNGE)</summary>
        SETL,
        ; <summary>Set byte if not greater or equal (SF!=OF) (SETL=SETNGE)</summary>
        SETNGE,
        ; <summary>Set byte if less or equal (ZF=1, SF!=OF) (SETLE=SETNG)</summary>
        SETLE,
        ; <summary>Set byte if not greater (ZF=1, SF!=OF) (SETLE=SETNG)</summary>
        SETNG,
        ; <summary>Set byte if sign (negative) (SF=1) (</summary>
        SETS,
        ; <summary>Set byte if not sign (non-negative) (SF=0)</summary>
        SETNS,
        ; <summary>Set byte if overflow (OF=1)</summary>
        SETO,
        ; <summary>Set byte if not overflow (OF=0)</summary>
        SETNO,
        ; <summary>Set byte if parity even (PF=1) (SETP=SETPE)</summary>
        SETPE,
        ; <summary>Set byte if parity (PF=1) (SETP=SETPE)</summary>
        SETP,
        ; <summary>Set byte if parity odd (PF=0) (SETNP=SETPO)</summary>
        SETPO,
        ; <summary>Set byte if not parity (PF=0) (SETNP=SETPO)</summary>
        SETNP,
        
        TEST,; Logical compare
        
        CRC32,; Provides hardware acceleration to calculate cyclic redundancy checks for fast and efficient implementation of data integrity protocols.
        
        POPCNT,; This instruction calculates of number of bits set to 1 in the second operand (source) and returns the count in the first operand (a destination register)
        #endregion
        #region Control Transfer Instructions
        ; The control transfer instructions provide jump, conditional jump, loop, and call and return operations to control
        ;program flow.
        ; <summary>Jump</summary>
        JMP,
        ; <summary>Jump if equal</summary>
        JE,
        ; <summary>Jump if zero</summary>
        JZ,
        ; <summary>Jump if not equal</summary>
        JNE,
        ; <summary>Jump if not zero</summary>
        JNZ,
        ; <summary>Jump if above</summary>
        JA,
        ; <summary>Jump if not below or equal</summary>
        JNBE,
        ; <summary>Jump if above or equal</summary>
        JAE,
        ; <summary>Jump if not below</summary>
        JNB,
        ; <summary>Jump if below</summary>
        JB,
        ; <summary>Jump if not above or equal</summary>
        JNAE,
        ; <summary>Jump if below or equal</summary>
        JBE,
        ; <summary>Jump if not above</summary>
        JNA,
        ; <summary>Jump if greater</summary>
        JG,
        ; <summary>Jump if not less or equal</summary>
        JNLE,
        ; <summary>Jump if greater or equal</summary>
        JGE,
        ; <summary>Jump if not less</summary>
        JNL,
        ; <summary>Jump if less</summary>
        JL,
        ; <summary>Jump if not greater or equal</summary>
        JNGE,
        ; <summary>Jump if less or equal</summary>
        JLE,
        ; <summary>Jump if not greater</summary>
        JNG,
        ; <summary>Jump if carry</summary>
        JC,
        ; <summary>Jump if not carry</summary>
        JNC,
        ; <summary>Jump if overflow</summary>
        JO,
        ; <summary>Jump if not overflow</summary>
        JNO, 
        ; <summary>Jump if sign (negative)</summary>
        JS,
        ; <summary>Jump if not sign (non-negative)</summary>
        JNS, 
        ; <summary>Jump if parity odd</summary>
        JPO,
        ; <summary>Jump if not parity</summary>
        JNP,
        ; <summary>Jump if parity eve</summary>
        JPE,
        ; <summary>Jump if parity</summary>
        JP,
        ; <summary> Jump register CX zero</summary>
        JCXZ,
        ; <summary>Jump register ECX zero</summary>
        JECXZ,
        ; <summary>Jump register RCX zero</summary>
        JRCXZ,
        ; <summary>Loop with ECX counter</summary>
        LOOP,
        ; <summary>Loop with ECX and zero</summary>
        LOOPZ,
        ; <summary>Loop with ECX and equal</summary>
        LOOPE,
        ; <summary>Loop with ECX and not zero</summary>
        LOOPNZ,
        ; <summary>Loop with ECX and not equal</summary>
        LOOPNE,
        ; <summary>Call procedure</summary>
        CALL,
        ; <summary>Return</summary>
        RET,
        ; <summary>Return from interrupt</summary>
        IRET,
        ; <summary>Software interrupt</summary>
        INT,
        ; <summary>Interrupt on overflow</summary>
        INTO,
        ; <summary>Detect value out of range</summary>
        BOUND,
        ; <summary>High-level procedure entry</summary>
        ENTER,
        ; <summary> High-level procedure exit</summary>
        LEAVE,
        #endregion
        #region string Instructions
        ;The string instructions operate on strings of bytes, allowing them to be moved to and from memory.
        
        MOVS,
        
        MOVSB,; Move string/Move byte string
        
        MOVSW,; Move string/Move word string
        
        MOVSD,; Move string/Move doubleword string
        
        CMPS,
        
        CMPSB,; Compare string/Compare byte string
        
        CMPSW,; Compare string/Compare word string
        
        CMPSD,; Compare string/Compare doubleword string
        
        SCAS,
        
        SCASB,; Scan string/Scan byte string
        
        SCASW,; Scan string/Scan word string
        
        SCASD,; Scan string/Scan doubleword string
        
        LODS,
        
        LODSB,; Load string/Load byte string
        
        LODSW,; Load string/Load word string
        
        LODSD,; Load string/Load doubleword string
        
        STOS,
        
        STOSB,; Store string/Store byte string
        
        STOSW,; Store string/Store word string
        
        STOSD,; Store string/Store doubleword string
        
        REP,; Repeat while ECX not zero
        
        REPE,
        
        REPZ,; Repeat while equal/Repeat while zero
        
        REPNE,
        
        REPNZ,; Repeat while not equal/Repeat while not zero
        #endregion
        #region I/O Instructions
        ;These instructions move data between the processors I/O ports and a register or memory.
        ;IN Read from a port
        
        OUT,; Write to a port
        
        INS,
        
        INSB,; Input string from port/Input byte string from port
        
        INSW,; Input string from port/Input word string from port
        
        INSD,; Input string from port/Input doubleword string from port
        
        OUTS,
        
        OUTSB,; Output string to port/Output byte string to port
        
        OUTSW,; Output string to port/Output word string to port
        
        OUTSD,; Output string to port/Output doubleword string to port
        #endregion
        #region Flag Control (EFLAG) Instructions
        ;The flag control instructions operate on the flags in the EFLAGS register.
        ; <summary>Set carry flag</summary>
        STC,
        ; <summary>Clear the carry flag</summary>
        CLC,
        ; <summary>Complement the carry flag</summary>
        CMC,
        ; <summary>Clear the direction flag</summary>
        CLD,
        ; <summary>Set direction flag</summary>
        STD,
        ; <summary>Load flags into AH register</summary>
        LAHF,
        ; <summary>Store AH register into flags</summary>
        SAHF,
        ; <summary>Push EFLAGS onto stack</summary>
        PUSHF,
        ; <summary></summary>
        PUSHFD,
        ; <summary>Pop EFLAGS from stack</summary>
        POPF,
        ; <summary>Pop EFLAGS from stack</summary>
        POPFD,
        ; <summary>Set interrupt flag</summary>
        STI,
        ; <summary>Clear the interrupt flag</summary>
        CLI,
        #endregion
        #region Segment Register Instructions
        ;The segment register instructions allow far pointers (segment addresses) to be loaded into the segment registers.
        
        LDS,; Load far pointer using DS
        
        LES,; Load far pointer using ES
        
        LFS,; Load far pointer using FS
        
        LGS,; Load far pointer using GS
        
        LSS,; Load far pointer using SS
        #endregion
        #region Miscellaneous Instructions
        ;The miscellaneous instructions provide such functions as loading an effective address, executing a no-operation,
        ;and retrieving processor identification information.
        ; <summary>Load effective address</summary>
        LEA,
        ; <summary> No operation</summary>
        NOP,
        ; <summary>Generates an invalid opcode. This instruction is provided for software testing to explicitly generate an invalid opcode. The opcode for this instruction is reserved for this purpose. Other than raising the invalid opcode exception, this instruction is the same as the NOP instruction.</summary>
        UD2,
        ; <summary>Table lookup translation</summary>
        XLAT,
        ; <summary>Table lookup translation</summary>
        XLATB, 
        ; <summary>Processor identification</summary>
        CPUID,
        ; <summary>Move data after swapping data bytes</summary>
        MOVBE,
        ; <summary>Prefetch data into cache in anticipation of write</summary>
        PREFETCHW,
        ; <summary>Prefetch hint T1 with intent to write</summary>
        PREFETCHWT1,
        ; <summary>Flushes and invalidates a memory operand and its associated cache line from all levels of the processors cache hierarchy</summary>
        CLFLUSH,
        ; <summary>Flushes and invalidates a memory operand and its associated cache line from all levels of the processors cache hierarchy with optimized memory system throughput</summary>
        CLFLUSHOPT,
        #endregion
        #region User Mode Extended Sate Save/Restore Instructions
        
        XSAVE,; Save processor extended states to memory
        
        XSAVEC,; Save processor extended states with compaction to memory
        
        XSAVEOPT,; Save processor extended states to memory, optimized
        
        XRSTOR,; Restore processor extended states from memory
        
        XGETBV,; Reads the state of an extended control register
        #endregion
        #region Random Number Generator Instructions
        
        RDRAND,; Retrieves a random number generated from hardware
        
        RDSEED,; Retrieves a random number generated from hardware
        #endregion
        #region BMI1, BMI2
        
        ANDN,; Bitwise AND of first source with inverted 2nd source operands.
        
        BEXTR,; Contiguous bitwise extract
        
        BLSI,; Extract lowest set bit
        
        BLSMSK,; Set all lower bits below first set bit to 1
        
        BLSR,; Reset lowest set bit
        
        BZHI,; Zero high bits starting from specified bit position

        ; <summary>Count the number leading zero bits</summary>
        LZCNT,
        ; <summary>Unsigned multiply without affecting arithmetic flags</summary>
        MULX,
        ; <summary>Parallel deposit of bits using a mask</summary>
        PDEP,
        ; <summary>Parallel extraction of bits using a mask</summary>
        PEXT,
        ; <summary>Rotate right without affecting arithmetic flags</summary>
        RORX,
        ; <summary>Shift arithmetic right</summary>
        SARX,
        ; <summary>Shift logic left</summary>
        SHLX,
        ; <summary>Shift logic right</summary>
        SHRX,
        ; <summary>Count the number trailing zero bits</summary>
        TZCNT,
        #endregion

        #region other
        ARPL,
        BB0_RESET,
        BB1_RESET,
        CDQE,
        CLTS,
        CMPSQ,
        CMPXCHG486,
        CMPXCHG16B,
        CPU_READ,
        CPU_WRITE,
        CQO,
        DMINT,
        EMMS,
        F2XM1,
        FABS,
        FADD,
        FADDP,
        FBLD,
        FBSTP,
        FCHS,
        FCLEX,
        FCMOVB,
        FCMOVBE,
        FCMOVE,
        FCMOVNB,
        FCMOVNBE,
        FCMOVNE,
        FCMOVNU,
        FCMOVU,
        FCOM,
        FCOMI,
        FCOMIP,
        FCOMP,
        FCOMPP,
        FCOS,
        FDECSTP,
        FDISI,
        FDIV,
        FDIVP,
        FDIVR,
        FDIVRP,
        FEMMS,
        FENI,
        FFREE,
        FFREEP,
        FIADD,
        FICOM,
        FICOMP,
        FIDIV,
        FIDIVR,
        FILD,
        FIMUL,
        FINCSTP,
        FINIT,
        FIST,
        FISTP,
        FISTTP,
        FISUB,
        FISUBR,
        FLD,
        FLD1,
        FLDCW,
        FLDENV,
        FLDL2E,
        FLDL2T,
        FLDLG2,
        FLDLN2,
        FLDPI,
        FLDZ,
        FMUL,
        FMULP,
        FNCLEX,
        FNDISI,
        FNENI,
        FNINIT,
        FNOP,
        FNSAVE,
        FNSTCW,
        FNSTENV,
        FNSTSW,
        FPATAN,
        FPREM,
        FPREM1,
        FPTAN,
        FRNDINT,
        FRSTOR,
        FSAVE,
        FSCALE,
        FSETPM,
        FSIN,
        FSINCOS,
        FSQRT,
        FST,
        FSTCW,
        FSTENV,
        FSTP,
        FSTSW,
        FSUB,
        FSUBP,
        FSUBR,
        FSUBRP,
        FTST,
        FUCOM,
        FUCOMI,
        FUCOMIP,
        FUCOMP,
        FUCOMPP,
        FXAM,
        FXCH,
        FXTRACT,
        FYL2X,
        FYL2XP1,
        HLT,
        IBTS,
        ICEBP,
        IN,
        INCBIN,
        INT01,
        INT1,
        INT03,
        INT3,
        INVD,
        INVPCID,
        INVLPG,
        INVLPGA,
        IRETD,
        IRETQ,
        IRETW,
        JMPE,
        LAR,
        LFENCE,
        LGDT,
        LIDT,
        LLDT,
        LMSW,
        LOADALL,
        LOADALL286,
        LODSQ,
        LSL,
        LTR,
        #endregion

        #region SSE/AVX
        MFENCE,
        MONITOR,
        MONITORX,
        MOVD,
        MOVQ,
        MOVSQ,
        MWAIT,
        MWAITX,
        PACKSSDW,
        PACKSSWB,
        PACKUSWB,
        PADDB,
        PADDD,
        PADDSB,
        PADDSW,
        PADDUSB,
        PADDUSW,
        PADDW,
        PAND,
        PANDN,
        PAUSE,
        PAVGUSB,
        PCMPEQB,
        PCMPEQD,
        PCMPEQW,
        PCMPGTB,
        PCMPGTD,
        PCMPGTW,
        PF2ID,
        PFACC,
        PFADD,
        PFCMPEQ,
        PFCMPGE,
        PFCMPGT,
        PFMAX,
        PFMIN,
        PFMUL,
        PFRCP,
        PFRCPIT1,
        PFRCPIT2,
        PFRSQIT1,
        PFRSQRT,
        PFSUB,
        PFSUBR,
        PI2FD,
        PMADDWD,
        PMULHRWA,
        PMULHRWC,
        PMULHW,
        PMULLW,
        POPAW,
        POPFQ,
        POPFW,
        POR,
        PREFETCH,
        PSLLD,
        PSLLQ,
        PSLLW,
        PSRAD,
        PSRAW,
        PSRLD,
        PSRLQ,
        PSRLW,
        PSUBB,
        PSUBD,
        PSUBSB,
        PSUBSW,
        PSUBUSB,
        PSUBUSW,
        PSUBW,
        PUNPCKHBW,
        PUNPCKHDQ,
        PUNPCKHWD,
        PUNPCKLBW,
        PUNPCKLDQ,
        PUNPCKLWD,
        PUSHAW,
        PUSHFQ,
        PUSHFW,
        PXOR,
        RDMSR,
        RDPMC,
        RDTSC,
        RDTSCP,
        RETF,
        RETN,
        RDM,
        RSDC,
        RSLDT,
        RSM,
        RSTS,
        SALC,
        SCASQ,
        SFENCE,
        SGDT,
        SIDT,
        SLDT,
        SKINIT,
        SMI,
        SMINT,
        SMINTOLD,
        SMSW,
        STOSQ,
        STR,
        SVDC,
        SVLDT,
        SVTS,
        SWAPGS,
        SYSCALL,
        SYSENTER,
        SYSEXIT,
        SYSRET,
        UD0,
        UD1,
        UD2B,
        UD2A,
        UMOV,
        VERR,
        VERW,
        FWAIT,
        WBINVD,
        WRSHR,
        WRMSR,
        XBTS,
        ADDPS,
        ADDSS,
        ANDNPS,
        ANDPS,
        CMPEQPS,
        CMPEQSS,
        CMPLEPS,
        CMPLESS,
        CMPLTPS,
        CMPLTSS,
        CMPNEQPS,
        CMPNEQSS,
        CMPNLEPS,
        CMPNLESS,
        CMPNLTPS,
        CMPNLTSS,
        CMPORDPS,
        CMPORDSS,
        CMPUNORDPS,
        CMPUNORDSS,
        CMPPS,
        CMPSS,
        COMISS,
        CVTPI2PS,
        CVTPS2PI,
        CVTSI2SS,
        CVTSS2SI,
        CVTTPS2PI,
        CVTTSS2SI,
        DIVPS,
        DIVSS,
        LDMXCSR,
        MAXPS,
        MAXSS,
        MINPS,
        MINSS,
        MOVAPS,
        MOVHPS,
        MOVLHPS,
        MOVLPS,
        MOVHLPS,
        MOVMSKPS,
        MOVNTPS,
        MOVSS,
        MOVUPS,
        MULPS,
        MULSS,
        ORPS,
        RCPPS,
        RCPSS,
        RSQRTPS,
        RSQRTSS,
        SHUFPS,
        SQRTPS,
        SQRTSS,
        STMXCSR,
        SUBPS,
        SUBSS,
        UCOMISS,
        UNPCKHPS,
        UNPCKLPS,
        FXRSTOR,
        FXRSTOR64,
        FXSAVE,
        FXSAVE64,
        XORPS,
        XORPD,
        XSETBV,
        XSAVE64,
        XSAVEC64,
        XSAVEOPT64,
        XSAVES,
        XSAVES64,
        XRSTOR64,
        XRSTORS,
        XRSTORS64,
        PREFETCHNTA,
        PREFETCHT0,
        PREFETCHT1,
        PREFETCHT2,
        MASKMOVQ,
        MOVNTQ,
        PAVGB,
        PAVGW,
        PEXTRW,
        PINSRW,
        PMAXSW,
        PMAXUB,
        PMINSW,
        PMINUB,
        PMOVMSKB,
        PMULHUW,
        PSADBW,
        PSHUFW,
        PF2IW,
        PFNACC,
        PFPNACC,
        PI2FW,
        PSWAPD,
        MASKMOVDQU,
        MOVNTDQ,
        MOVNTI,
        MOVNTPD,
        MOVDQA,
        MOVDQU,
        MOVDQ2Q,
        MOVQ2DQ,
        PADDQ,
        PMULUDQ,
        PSHUFD,
        PSHUFHW,
        PSHUFLW,
        PSLLDQ,
        PSRLDQ,
        PSUBQ,
        PUNPCKHQDQ,
        PUNPCKLQDQ,
        ADDPD,
        ADDSD,
        ANDNPD,
        ANDPD,
        CMPEQPD,
        CMPEQSD,
        CMPLEPD,
        CMPLESD,
        CMPLTPD,
        CMPLTSD,
        CMPNEQPD,
        CMPNEQSD,
        CMPNLEPD,
        CMPNLESD,
        CMPNLTPD,
        CMPNLTSD,
        CMPORDPD,
        CMPORDSD,
        CMPUNORDPD,
        CMPUNORDSD,
        CMPPD,
        COMISD,
        CVTDQ2PD,
        CVTDQ2PS,
        CVTPD2DQ,
        CVTPD2PI,
        CVTPD2PS,
        CVTPI2PD,
        CVTPS2DQ,
        CVTPS2PD,
        CVTSD2SI,
        CVTSD2SS,
        CVTSI2SD,
        CVTSS2SD,
        CVTTPD2PI,
        CVTTPD2DQ,
        CVTTPS2DQ,
        CVTTSD2SI,
        DIVPD,
        DIVSD,
        MAXPD,
        MAXSD,
        MINPD,
        MINSD,
        MOVAPD,
        MOVHPD,
        MOVLPD,
        MOVMSKPD,
        MOVUPD,
        MULPD,
        MULSD,
        ORPD,
        SHUFPD,
        SQRTPD,
        SQRTSD,
        SUBPD,
        SUBSD,
        UCOMISD,
        UNPCKHPD,
        UNPCKLPD,
        ADDSUBPD,
        ADDSUBPS,
        HADDPD,
        HADDPS,
        HSUBPD,
        HSUBPS,
        LDDQU,
        MOVDDUP,
        MOVSHDUP,
        MOVSLDUP,
        CLGI,
        STGI,
        VMCALL,
        VMCLEAR,
        VMFUNC,
        VMLAUNCH,
        VMLOAD,
        VMMCALL,
        VMPTRLD,
        VMPTRST,
        VMREAD,
        VMRESUME,
        VMRUN,
        VMSAVE,
        VMWRITE,
        VMXOFF,
        VMXON,
        INVEPT,
        INVVPID,
        PABSB,
        PABSW,
        PABSD,
        PALIGNR,
        PHADDW,
        PHADDD,
        PHADDSW,
        PHSUBW,
        PHSUBD,
        PHSUBSW,
        PMADDUBSW,
        PMULHRSW,
        PSHUFB,
        PSIGNB,
        PSIGNW,
        PSIGND,
        EXTRQ,
        INSERTQ,
        MOVNTSD,
        MOVNTSS,
        BLENDPD,
        BLENDPS,
        BLENDVPD,
        BLENDVPS,
        DPPD,
        DPPS,
        EXTRACTPS,
        INSERTPS,
        MOVNTDQA,
        MPSADBW,
        PACKUSDW,
        PBLENDVB,
        PBLENDW,
        PCMPEQQ,
        PEXTRB,
        PEXTRD,
        PEXTRQ,
        PHMINPOSUW,
        PINSRB,
        PINSRD,
        PINSRQ,
        PMAXSB,
        PMAXSD,
        PMAXUD,
        PMAXUW,
        PMINSB,
        PMINSD,
        PMINUD,
        PMINUW,
        PMOVSXBW,
        PMOVSXBD,
        PMOVSXBQ,
        PMOVSXWD,
        PMOVSXWQ,
        PMOVSXDQ,
        PMOVZXBW,
        PMOVZXBD,
        PMOVZXBQ,
        PMOVZXWD,
        PMOVZXWQ,
        PMOVZXDQ,
        PMULDQ,
        PMULLD,
        PTEST,
        ROUNDPD,
        ROUNDPS,
        ROUNDSD,
        ROUNDSS,
        PCMPESTRI,
        PCMPESTRM,
        PCMPISTRI,
        PCMPISTRM,
        PCMPGTQ,
        GETSEC,
        PFRCPV,
        PFRSQRTV,
        AESENC,
        AESENCLAST,
        AESDEC,
        AESDECLAST,
        AESIMC,
        AESKEYGENASSIST,
        VAESENC,
        VAESENCLAST,
        VAESDEC,
        VAESDECLAST,
        VAESIMC,
        VAESKEYGENASSIST,
        VADDPD,
        VADDPS,
        VADDSD,
        VADDSS,
        VADDSUBPD,
        VADDSUBPS,
        VANDPD,
        VANDPS,
        VANDNPD,
        VANDNPS,
        VBLENDPD,
        VBLENDPS,
        VBLENDVPD,
        VBLENDVPS,
        VBROADCASTSS,
        VBROADCASTSD,
        VBROADCASTF128,
        VCMPEQ_OSPD,
        VCMPEQPD,
        VCMPLT_OSPD,
        VCMPLTPD,
        VCMPLE_OSPD,
        VCMPLEPD,
        VCMPUNORD_QPD,
        VCMPUNORDPD,
        VCMPNEQ_UQPD,
        VCMPNEQPD,
        VCMPNLT_USPD,
        VCMPNLTPD,
        VCMPNLE_USPD,
        VCMPNLEPD,
        VCMPORD_QPD,
        VCMPORDPD,
        VCMPEQ_UQPD,
        VCMPNGE_USPD,
        VCMPNGEPD,
        VCMPNGT_USPD,
        VCMPNGTPD,
        VCMPFALSE_OQPD,
        VCMPFALSEPD,
        VCMPNEQ_OQPD,
        VCMPGE_OSPD,
        VCMPGEPD,
        VCMPGT_OSPD,
        VCMPGTPD,
        VCMPTRUE_UQPD,
        VCMPTRUEPD,
        VCMPLT_OQPD,
        VCMPLE_OQPD,
        VCMPUNORD_SPD,
        VCMPNEQ_USPD,
        VCMPNLT_UQPD,
        VCMPNLE_UQPD,
        VCMPORD_SPD,
        VCMPEQ_USPD,
        VCMPNGE_UQPD,
        VCMPNGT_UQPD,
        VCMPFALSE_OSPD,
        VCMPNEQ_OSPD,
        VCMPGE_OQPD,
        VCMPGT_OQPD,
        VCMPTRUE_USPD,
        VCMPPD,
        VCMPEQ_OSPS,
        VCMPEQPS,
        VCMPLT_OSPS,
        VCMPLTPS,
        VCMPLE_OSPS,
        VCMPLEPS,
        VCMPUNORD_QPS,
        VCMPUNORDPS,
        VCMPNEQ_UQPS,
        VCMPNEQPS,
        VCMPNLT_USPS,
        VCMPNLTPS,
        VCMPNLE_USPS,
        VCMPNLEPS,
        VCMPORD_QPS,
        VCMPORDPS,
        VCMPEQ_UQPS,
        VCMPNGE_USPS,
        VCMPNGEPS,
        VCMPNGT_USPS,
        VCMPNGTPS,
        VCMPFALSE_OQPS,
        VCMPFALSEPS,
        VCMPNEQ_OQPS,
        VCMPGE_OSPS,
        VCMPGEPS,
        VCMPGT_OSPS,
        VCMPGTPS,
        VCMPTRUE_UQPS,
        VCMPTRUEPS,
        VCMPLT_OQPS,
        VCMPLE_OQPS,
        VCMPUNORD_SPS,
        VCMPNEQ_USPS,
        VCMPNLT_UQPS,
        VCMPNLE_UQPS,
        VCMPORD_SPS,
        VCMPEQ_USPS,
        VCMPNGE_UQPS,
        VCMPNGT_UQPS,
        VCMPFALSE_OSPS,
        VCMPNEQ_OSPS,
        VCMPGE_OQPS,
        VCMPGT_OQPS,
        VCMPTRUE_USPS,
        VCMPPS,
        VCMPEQ_OSSD,
        VCMPEQSD,
        VCMPLT_OSSD,
        VCMPLTSD,
        VCMPLE_OSSD,
        VCMPLESD,
        VCMPUNORD_QSD,
        VCMPUNORDSD,
        VCMPNEQ_UQSD,
        VCMPNEQSD,
        VCMPNLT_USSD,
        VCMPNLTSD,
        VCMPNLE_USSD,
        VCMPNLESD,
        VCMPORD_QSD,
        VCMPORDSD,
        VCMPEQ_UQSD,
        VCMPNGE_USSD,
        VCMPNGESD,
        VCMPNGT_USSD,
        VCMPNGTSD,
        VCMPFALSE_OQSD,
        VCMPFALSESD,
        VCMPNEQ_OQSD,
        VCMPGE_OSSD,
        VCMPGESD,
        VCMPGT_OSSD,
        VCMPGTSD,
        VCMPTRUE_UQSD,
        VCMPTRUESD,
        VCMPLT_OQSD,
        VCMPLE_OQSD,
        VCMPUNORD_SSD,
        VCMPNEQ_USSD,
        VCMPNLT_UQSD,
        VCMPNLE_UQSD,
        VCMPORD_SSD,
        VCMPEQ_USSD,
        VCMPNGE_UQSD,
        VCMPNGT_UQSD,
        VCMPFALSE_OSSD,
        VCMPNEQ_OSSD,
        VCMPGE_OQSD,
        VCMPGT_OQSD,
        VCMPTRUE_USSD,
        VCMPSD,
        VCMPEQ_OSSS,
        VCMPEQSS,
        VCMPLT_OSSS,
        VCMPLTSS,
        VCMPLE_OSSS,
        VCMPLESS,
        VCMPUNORD_QSS,
        VCMPUNORDSS,
        VCMPNEQ_UQSS,
        VCMPNEQSS,
        VCMPNLT_USSS,
        VCMPNLTSS,
        VCMPNLE_USSS,
        VCMPNLESS,
        VCMPORD_QSS,
        VCMPORDSS,
        VCMPEQ_UQSS,
        VCMPNGE_USSS,
        VCMPNGESS,
        VCMPNGT_USSS,
        VCMPNGTSS,
        VCMPFALSE_OQSS,
        VCMPFALSESS,
        VCMPNEQ_OQSS,
        VCMPGE_OSSS,
        VCMPGESS,
        VCMPGT_OSSS,
        VCMPGTSS,
        VCMPTRUE_UQSS,
        VCMPTRUESS,
        VCMPLT_OQSS,
        VCMPLE_OQSS,
        VCMPUNORD_SSS,
        VCMPNEQ_USSS,
        VCMPNLT_UQSS,
        VCMPNLE_UQSS,
        VCMPORD_SSS,
        VCMPEQ_USSS,
        VCMPNGE_UQSS,
        VCMPNGT_UQSS,
        VCMPFALSE_OSSS,
        VCMPNEQ_OSSS,
        VCMPGE_OQSS,
        VCMPGT_OQSS,
        VCMPTRUE_USSS,
        VCMPSS,
        VCOMISD,
        VCOMISS,
        VCVTDQ2PD,
        VCVTDQ2PS,
        VCVTPD2DQ,
        VCVTPD2PS,
        VCVTPS2DQ,
        VCVTPS2PD,
        VCVTSD2SI,
        VCVTSD2SS,
        VCVTSI2SD,
        VCVTSI2SS,
        VCVTSS2SD,
        VCVTSS2SI,
        VCVTTPD2DQ,
        VCVTTPS2DQ,
        VCVTTSD2SI,
        VCVTTSS2SI,
        VDIVPD,
        VDIVPS,
        VDIVSD,
        VDIVSS,
        VDPPD,
        VDPPS,
        VEXTRACTF128,
        VEXTRACTPS,
        VHADDPD,
        VHADDPS,
        VHSUBPD,
        VHSUBPS,
        VINSERTF128,
        VINSERTPS,
        VLDDQU,
        VLDQQU,
        VLDMXCSR,
        VMASKMOVDQU,
        VMASKMOVPS,
        VMASKMOVPD,
        VMAXPD,
        VMAXPS,
        VMAXSD,
        VMAXSS,
        VMINPD,
        VMINPS,
        VMINSD,
        VMINSS,
        VMOVAPD,
        VMOVAPS,
        VMOVD,
        VMOVQ,
        VMOVDDUP,
        VMOVDQA,
        VMOVQQA,
        VMOVDQU,
        VMOVQQU,
        VMOVHLPS,
        VMOVHPD,
        VMOVHPS,
        VMOVLHPS,
        VMOVLPD,
        VMOVLPS,
        VMOVMSKPD,
        VMOVMSKPS,
        VMOVNTDQ,
        VMOVNTQQ,
        VMOVNTDQA,
        VMOVNTPD,
        VMOVNTPS,
        VMOVSD,
        VMOVSHDUP,
        VMOVSLDUP,
        VMOVSS,
        VMOVUPD,
        VMOVUPS,
        VMPSADBW,
        VMULPD,
        VMULPS,
        VMULSD,
        VMULSS,
        VORPD,
        VORPS,
        VPABSB,
        VPABSW,
        VPABSD,
        VPACKSSWB,
        VPACKSSDW,
        VPACKUSWB,
        VPACKUSDW,
        VPADDB,
        VPADDW,
        VPADDD,
        VPADDQ,
        VPADDSB,
        VPADDSW,
        VPADDUSB,
        VPADDUSW,
        VPALIGNR,
        VPAND,
        VPANDN,
        VPAVGB,
        VPAVGW,
        VPBLENDVB,
        VPBLENDW,
        VPCMPESTRI,
        VPCMPESTRM,
        VPCMPISTRI,
        VPCMPISTRM,
        VPCMPEQB,
        VPCMPEQW,
        VPCMPEQD,
        VPCMPEQQ,
        VPCMPGTB,
        VPCMPGTW,
        VPCMPGTD,
        VPCMPGTQ,
        VPERMILPD,
        VPERMILPS,
        VPERM2F128,
        VPEXTRB,
        VPEXTRW,
        VPEXTRD,
        VPEXTRQ,
        VPHADDW,
        VPHADDD,
        VPHADDSW,
        VPHMINPOSUW,
        VPHSUBW,
        VPHSUBD,
        VPHSUBSW,
        VPINSRB,
        VPINSRW,
        VPINSRD,
        VPINSRQ,
        VPMADDWD,
        VPMADDUBSW,
        VPMAXSB,
        VPMAXSW,
        VPMAXSD,
        VPMAXUB,
        VPMAXUW,
        VPMAXUD,
        VPMINSB,
        VPMINSW,
        VPMINSD,
        VPMINUB,
        VPMINUW,
        VPMINUD,
        VPMOVMSKB,
        VPMOVSXBW,
        VPMOVSXBD,
        VPMOVSXBQ,
        VPMOVSXWD,
        VPMOVSXWQ,
        VPMOVSXDQ,
        VPMOVZXBW,
        VPMOVZXBD,
        VPMOVZXBQ,
        VPMOVZXWD,
        VPMOVZXWQ,
        VPMOVZXDQ,
        VPMULHUW,
        VPMULHRSW,
        VPMULHW,
        VPMULLW,
        VPMULLD,
        VPMULUDQ,
        VPMULDQ,
        VPOR,
        VPSADBW,
        VPSHUFB,
        VPSHUFD,
        VPSHUFHW,
        VPSHUFLW,
        VPSIGNB,
        VPSIGNW,
        VPSIGND,
        VPSLLDQ,
        VPSRLDQ,
        VPSLLW,
        VPSLLD,
        VPSLLQ,
        VPSRAW,
        VPSRAD,
        VPSRLW,
        VPSRLD,
        VPSRLQ,
        VPTEST,
        VPSUBB,
        VPSUBW,
        VPSUBD,
        VPSUBQ,
        VPSUBSB,
        VPSUBSW,
        VPSUBUSB,
        VPSUBUSW,
        VPUNPCKHBW,
        VPUNPCKHWD,
        VPUNPCKHDQ,
        VPUNPCKHQDQ,
        VPUNPCKLBW,
        VPUNPCKLWD,
        VPUNPCKLDQ,
        VPUNPCKLQDQ,
        VPXOR,
        VRCPPS,
        VRCPSS,
        VRSQRTPS,
        VRSQRTSS,
        VROUNDPD,
        VROUNDPS,
        VROUNDSD,
        VROUNDSS,
        VSHUFPD,
        VSHUFPS,
        VSQRTPD,
        VSQRTPS,
        VSQRTSD,
        VSQRTSS,
        VSTMXCSR,
        VSUBPD,
        VSUBPS,
        VSUBSD,
        VSUBSS,
        VTESTPS,
        VTESTPD,
        VUCOMISD,
        VUCOMISS,
        VUNPCKHPD,
        VUNPCKHPS,
        VUNPCKLPD,
        VUNPCKLPS,
        VXORPD,
        VXORPS,
        VZEROALL,
        VZEROUPPER,
        PCLMULLQLQDQ,
        PCLMULHQLQDQ,
        PCLMULLQHQDQ,
        PCLMULHQHQDQ,
        PCLMULQDQ,
        VPCLMULLQLQDQ,
        VPCLMULHQLQDQ,
        VPCLMULLQHQDQ,
        VPCLMULHQHQDQ,
        VPCLMULQDQ,
        VFMADD132PS,
        VFMADD132PD,
        VFMADD312PS,
        VFMADD312PD,
        VFMADD213PS,
        VFMADD213PD,
        VFMADD123PS,
        VFMADD123PD,
        VFMADD231PS,
        VFMADD231PD,
        VFMADD321PS,
        VFMADD321PD,
        VFMADDSUB132PS,
        VFMADDSUB132PD,
        VFMADDSUB312PS,
        VFMADDSUB312PD,
        VFMADDSUB213PS,
        VFMADDSUB213PD,
        VFMADDSUB123PS,
        VFMADDSUB123PD,
        VFMADDSUB231PS,
        VFMADDSUB231PD,
        VFMADDSUB321PS,
        VFMADDSUB321PD,
        VFMSUB132PS,
        VFMSUB132PD,
        VFMSUB312PS,
        VFMSUB312PD,
        VFMSUB213PS,
        VFMSUB213PD,
        VFMSUB123PS,
        VFMSUB123PD,
        VFMSUB231PS,
        VFMSUB231PD,
        VFMSUB321PS,
        VFMSUB321PD,
        VFMSUBADD132PS,
        VFMSUBADD132PD,
        VFMSUBADD312PS,
        VFMSUBADD312PD,
        VFMSUBADD213PS,
        VFMSUBADD213PD,
        VFMSUBADD123PS,
        VFMSUBADD123PD,
        VFMSUBADD231PS,
        VFMSUBADD231PD,
        VFMSUBADD321PS,
        VFMSUBADD321PD,
        VFNMADD132PS,
        VFNMADD132PD,
        VFNMADD312PS,
        VFNMADD312PD,
        VFNMADD213PS,
        VFNMADD213PD,
        VFNMADD123PS,
        VFNMADD123PD,
        VFNMADD231PS,
        VFNMADD231PD,
        VFNMADD321PS,
        VFNMADD321PD,
        VFNMSUB132PS,
        VFNMSUB132PD,
        VFNMSUB312PS,
        VFNMSUB312PD,
        VFNMSUB213PS,
        VFNMSUB213PD,
        VFNMSUB123PS,
        VFNMSUB123PD,
        VFNMSUB231PS,
        VFNMSUB231PD,
        VFNMSUB321PS,
        VFNMSUB321PD,
        VFMADD132SS,
        VFMADD132SD,
        VFMADD312SS,
        VFMADD312SD,
        VFMADD213SS,
        VFMADD213SD,
        VFMADD123SS,
        VFMADD123SD,
        VFMADD231SS,
        VFMADD231SD,
        VFMADD321SS,
        VFMADD321SD,
        VFMSUB132SS,
        VFMSUB132SD,
        VFMSUB312SS,
        VFMSUB312SD,
        VFMSUB213SS,
        VFMSUB213SD,
        VFMSUB123SS,
        VFMSUB123SD,
        VFMSUB231SS,
        VFMSUB231SD,
        VFMSUB321SS,
        VFMSUB321SD,
        VFNMADD132SS,
        VFNMADD132SD,
        VFNMADD312SS,
        VFNMADD312SD,
        VFNMADD213SS,
        VFNMADD213SD,
        VFNMADD123SS,
        VFNMADD123SD,
        VFNMADD231SS,
        VFNMADD231SD,
        VFNMADD321SS,
        VFNMADD321SD,
        VFNMSUB132SS,
        VFNMSUB132SD,
        VFNMSUB312SS,
        VFNMSUB312SD,
        VFNMSUB213SS,
        VFNMSUB213SD,
        VFNMSUB123SS,
        VFNMSUB123SD,
        VFNMSUB231SS,
        VFNMSUB231SD,
        VFNMSUB321SS,
        VFNMSUB321SD,
        RDFSBASE,
        RDGSBASE,
        WRFSBASE,
        WRGSBASE,
        VCVTPH2PS,
        VCVTPS2PH,
        CLAC,
        STAC,
        XSTORE,
        XCRYPTECB,
        XCRYPTCBC,
        XCRYPTCTR,
        XCRYPTCFB,
        XCRYPTOFB,
        MONTMUL,
        XSHA1,
        XSHA256,
        LLWPCB,
        SLWPCB,
        LWPVAL,
        LWPINS,
        VFMADDPD,
        VFMADDPS,
        VFMADDSD,
        VFMADDSS,
        VFMADDSUBPD,
        VFMADDSUBPS,
        VFMSUBADDPD,
        VFMSUBADDPS,
        VFMSUBPD,
        VFMSUBPS,
        VFMSUBSD,
        VFMSUBSS,
        VFNMADDPD,
        VFNMADDPS,
        VFNMADDSD,
        VFNMADDSS,
        VFNMSUBPD,
        VFNMSUBPS,
        VFNMSUBSD,
        VFNMSUBSS,
        VFRCZPD,
        VFRCZPS,
        VFRCZSD,
        VFRCZSS,
        VPCMOV,
        VPCOMB,
        VPCOMD,
        VPCOMQ,
        VPCOMUB,
        VPCOMUD,
        VPCOMUQ,
        VPCOMUW,
        VPCOMW,
        VPHADDBD,
        VPHADDBQ,
        VPHADDBW,
        VPHADDDQ,
        VPHADDUBD,
        VPHADDUBQ,
        VPHADDUBW,
        VPHADDUDQ,
        VPHADDUWD,
        VPHADDUWQ,
        VPHADDWD,
        VPHADDWQ,
        VPHSUBBW,
        VPHSUBDQ,
        VPHSUBWD,
        VPMACSDD,
        VPMACSDQH,
        VPMACSDQL,
        VPMACSSDD,
        VPMACSSDQH,
        VPMACSSDQL,
        VPMACSSWD,
        VPMACSSWW,
        VPMACSWD,
        VPMACSWW,
        VPMADCSSWD,
        VPMADCSWD,
        VPPERM,
        VPROTB,
        VPROTD,
        VPROTQ,
        VPROTW,
        VPSHAB,
        VPSHAD,
        VPSHAQ,
        VPSHAW,
        VPSHLB,
        VPSHLD,
        VPSHLQ,
        VPSHLW,
        VBROADCASTI128,
        VPBLENDD,
        VPBROADCASTB,
        VPBROADCASTW,
        VPBROADCASTD,
        VPBROADCASTQ,
        VPERMD,
        VPERMPD,
        VPERMPS,
        VPERMQ,
        VPERM2I128,
        VEXTRACTI128,
        VINSERTI128,
        VPMASKMOVD,
        VPMASKMOVQ,
        VPSLLVD,
        VPSLLVQ,
        VPSRAVD,
        VPSRLVD,
        VPSRLVQ,
        VGATHERDPD,
        VGATHERQPD,
        VGATHERDPS,
        VGATHERQPS,
        VPGATHERDD,
        VPGATHERQD,
        VPGATHERDQ,
        VPGATHERQQ,
        XABORT,
        XBEGIN,
        XEND,
        XTEST,
        BLCI,
        BLCIC,
        BLSIC,
        BLCFILL,
        BLSFILL,
        BLCMSK,
        BLCS,
        TZMSK,
        T1MSKC,
        BNDMK,
        BNDCL,
        BNDCU,
        BNDCN,
        BNDMOV,
        BNDLDX,
        BNDSTX,
        KADDB,
        KADDD,
        KADDQ,
        KADDW,
        KANDB,
        KANDD,
        KANDNB,
        KANDND,
        KANDNQ,
        KANDNW,
        KANDQ,
        KANDW,
        KMOVB,
        KMOVD,
        KMOVQ,
        KMOVW,
        KNOTB,
        KNOTD,
        KNOTQ,
        KNOTW,
        KORB,
        KORD,
        KORQ,
        KORTESTB,
        KORTESTD,
        KORTESTQ,
        KORTESTW,
        KORW,
        KSHIFTLB,
        KSHIFTLD,
        KSHIFTLQ,
        KSHIFTLW,
        KSHIFTRB,
        KSHIFTRD,
        KSHIFTRQ,
        KSHIFTRW,
        KTESTB,
        KTESTD,
        KTESTQ,
        KTESTW,
        KUNPCKBW,
        KUNPCKDQ,
        KUNPCKWD,
        KXNORB,
        KXNORD,
        KXNORQ,
        KXNORW,
        KXORB,
        KXORD,
        KXORQ,
        KXORW,
        SHA1MSG1,
        SHA1MSG2,
        SHA1NEXTE,
        SHA1RNDS4,
        SHA256MSG1,
        SHA256MSG2,
        SHA256RNDS2,
        VALIGND,
        VALIGNQ,
        VBLENDMPD,
        VBLENDMPS,
        VBROADCASTF32X2,
        VBROADCASTF32X4,
        VBROADCASTF32X8,
        VBROADCASTF64X2,
        VBROADCASTF64X4,
        VBROADCASTI32X2,
        VBROADCASTI32X4,
        VBROADCASTI32X8,
        VBROADCASTI64X2,
        VBROADCASTI64X4,
        VCOMPRESSPD,
        VCOMPRESSPS,
        VCVTPD2QQ,
        VCVTPD2UDQ,
        VCVTPD2UQQ,
        VCVTPS2QQ,
        VCVTPS2UDQ,
        VCVTPS2UQQ,
        VCVTQQ2PD,
        VCVTQQ2PS,
        VCVTSD2USI,
        VCVTSS2USI,
        VCVTTPD2QQ,
        VCVTTPD2UDQ,
        VCVTTPD2UQQ,
        VCVTTPS2QQ,
        VCVTTPS2UDQ,
        VCVTTPS2UQQ,
        VCVTTSD2USI,
        VCVTTSS2USI,
        VCVTUDQ2PD,
        VCVTUDQ2PS,
        VCVTUQQ2PD,
        VCVTUQQ2PS,
        VCVTUSI2SD,
        VCVTUSI2SS,
        VDBPSADBW,
        VEXP2PD,
        VEXP2PS,
        VEXPANDPD,
        VEXPANDPS,
        VEXTRACTF32X4,
        VEXTRACTF32X8,
        VEXTRACTF64X2,
        VEXTRACTF64X4,
        VEXTRACTI32X4,
        VEXTRACTI32X8,
        VEXTRACTI64X2,
        VEXTRACTI64X4,
        VFIXUPIMMPD,
        VFIXUPIMMPS,
        VFIXUPIMMSD,
        VFIXUPIMMSS,
        VFPCLASSPD,
        VFPCLASSPS,
        VFPCLASSSD,
        VFPCLASSSS,
        VGATHERPF0DPD,
        VGATHERPF0DPS,
        VGATHERPF0QPD,
        VGATHERPF0QPS,
        VGATHERPF1DPD,
        VGATHERPF1DPS,
        VGATHERPF1QPD,
        VGATHERPF1QPS,
        VGETEXPPD,
        VGETEXPPS,
        VGETEXPSD,
        VGETEXPSS,
        VGETMANTPD,
        VGETMANTPS,
        VGETMANTSD,
        VGETMANTSS,
        VINSERTF32X4,
        VINSERTF32X8,
        VINSERTF64X2,
        VINSERTF64X4,
        VINSERTI32X4,
        VINSERTI32X8,
        VINSERTI64X2,
        VINSERTI64X4,
        VMOVDQA32,
        VMOVDQA64,
        VMOVDQU16,
        VMOVDQU32,
        VMOVDQU64,
        VMOVDQU8,
        VPABSQ,
        VPANDD,
        VPANDND,
        VPANDNQ,
        VPANDQ,
        VPBLENDMB,
        VPBLENDMD,
        VPBLENDMQ,
        VPBLENDMW,
        VPBROADCASTMB2Q,
        VPBROADCASTMW2D,
        VPCMPB,
        VPCMPD,
        VPCMPQ,
        VPCMPUB,
        VPCMPUD,
        VPCMPUQ,
        VPCMPUW,
        VPCMPW,
        VPCOMPRESSD,
        VPCOMPRESSQ,
        VPCONFLICTD,
        VPCONFLICTQ,
        VPERMB,
        VPERMI2B,
        VPERMI2D,
        VPERMI2PD,
        VPERMI2PS,
        VPERMI2Q,
        VPERMI2W,
        VPERMT2B,
        VPERMT2D,
        VPERMT2PD,
        VPERMT2PS,
        VPERMT2Q,
        VPERMT2W,
        VPERMW,
        VPEXPANDD,
        VPEXPANDQ,
        VPLZCNTD,
        VPLZCNTQ,
        VPMADD52HUQ,
        VPMADD52LUQ,
        VPMAXSQ,
        VPMAXUQ,
        VPMINSQ,
        VPMINUQ,
        VPMOVB2M,
        VPMOVD2M,
        VPMOVDB,
        VPMOVDW,
        VPMOVM2B,
        VPMOVM2D,
        VPMOVM2Q,
        VPMOVM2W,
        VPMOVQ2M,
        VPMOVQB,
        VPMOVQD,
        VPMOVQW,
        VPMOVSDB,
        VPMOVSDW,
        VPMOVSQB,
        VPMOVSQD,
        VPMOVSQW,
        VPMOVSWB,
        VPMOVUSDB,
        VPMOVUSDW,
        VPMOVUSQB,
        VPMOVUSQD,
        VPMOVUSQW,
        VPMOVUSWB,
        VPMOVW2M,
        VPMOVWB,
        VPMULLQ,
        VPMULTISHIFTQB,
        VPORD,
        VPORQ,
        VPROLD,
        VPROLQ,
        VPROLVD,
        VPROLVQ,
        VPRORD,
        VPRORQ,
        VPRORVD,
        VPRORVQ,
        VPSCATTERDD,
        VPSCATTERDQ,
        VPSCATTERQD,
        VPSCATTERQQ,
        VPSLLVW,
        VPSRAQ,
        VPSRAVQ,
        VPSRAVW,
        VPSRLVW,
        VPTERNLOGD,
        VPTERNLOGQ,
        VPTESTMB,
        VPTESTMD,
        VPTESTMQ,
        VPTESTMW,
        VPTESTNMB,
        VPTESTNMD,
        VPTESTNMQ,
        VPTESTNMW,
        VPXORD,
        VPXORQ,
        VRANGEPD,
        VRANGEPS,
        VRANGESD,
        VRANGESS,
        VRCP14PD,
        VRCP14PS,
        VRCP14SD,
        VRCP14SS,
        VRCP28PD,
        VRCP28PS,
        VRCP28SD,
        VRCP28SS,
        VREDUCEPD,
        VREDUCEPS,
        VREDUCESD,
        VREDUCESS,
        VRNDSCALEPD,
        VRNDSCALEPS,
        VRNDSCALESD,
        VRNDSCALESS,
        VRSQRT14PD,
        VRSQRT14PS,
        VRSQRT14SD,
        VRSQRT14SS,
        VRSQRT28PD,
        VRSQRT28PS,
        VRSQRT28SD,
        VRSQRT28SS,
        VSCALEFPD,
        VSCALEFPS,
        VSCALEFSD,
        VSCALEFSS,
        VSCATTERDPD,
        VSCATTERDPS,
        VSCATTERPF0DPD,
        VSCATTERPF0DPS,
        VSCATTERPF0QPD,
        VSCATTERPF0QPS,
        VSCATTERPF1DPD,
        VSCATTERPF1DPS,
        VSCATTERPF1QPD,
        VSCATTERPF1QPS,
        VSCATTERQPD,
        VSCATTERQPS,
        VSHUFF32X4,
        VSHUFF64X2,
        VSHUFI32X4,
        VSHUFI64X2,
        RDPKRU,
        WRPKRU,
        CLZERO,

        XRELEASE,
        XACQUIRE,
        WAIT,
        LOCK,

        PABSQ,
        PMAXSQ,
        PMAXUQ,
        PMINSQ,
        PMINUQ,
        PMULLQ,
        PROLVD,
        PROLVQ,
        PROLD,
        PROLQ,
        PRORQ,
        PRORD,
        PRORVQ,
        PRORVD,
        PSRAQ,
        PTWRITE,
        RDPID,
        #endregion

        #region CYRIX
        ; <summary>CYRIX: Packed Add with Saturation.</summary>
        PADDSIW,
        ; <summary>CYRIX: Packed Subtract with Saturation.</summary>
        PSUBSIW,
        ; <summary>CYRIX: Packed Average.</summary>
        PAVEB,
        ; <summary>CYRIX: Packed Distance and Accumulate.</summary>
        PDISTIB,
        ; <summary>CYRIX: Packed Multiply and Accumulate with Rounding.</summary>
        PMACHRIW,
        ; <summary>CYRIX: Packed Magnitude.</summary>
        PMAGW,
        ; <summary>CYRIX: Packed Multiply High with Rounding.</summary>
        PMULHRW,
        ; <summary>CYRIX: Packed Multiply High with Rounding using implied destination.</summary>
        PMULHRIW,
        ; <summary>CYRIX: Packed Conditional Move(zero).</summary>
        PMVZB,
        ; <summary>CYRIX: Packed Conditional Move(not zero).</summary>
        PMVNZB,
        ; <summary>CYRIX: Packed Conditional Move(less than zero).</summary>
        PMVLZB,
        ; <summary>CYRIX: Packed Conditional Move(greater than or equal to zero).</summary>
        PMVGEZB,

        ; <summary>CYRIXM</summary>
        RDSHR,
        #endregion


		#region Intel Architecture Instruction Set Extensions Programming Reference (APRIL 2017)
        
		VPERMT2W
		VPERMT2D
		VPERMT2Q
		VPERMT2PS
		VPERMT2PD

        ; <summary>Packed Single-Precision Floating-Point Fused Multiply-Add (4-iterations)</summary>
        V4FMADDPS 
        ; <summary>Packed Single-Precision Floating-Point Fused Multiply-Add (4-iterations)</summary>
        V4FNMADDPS 
        ; <summary>Scalar Single-Precision Floating-Point Fused Multiply-Add (4-iterations)</summary>
        V4FMADDSS 
        ; <summary>Scalar Single-Precision Floating-Point Fused Multiply-Add (4-iterations)</summary>
        V4FNMADDSS 


        ; <summary>Dot Product of Signed Words with Dword Accumulation (4-iterations)</summary>
        VP4DPWSSD 
        ; <summary>Dot Product of Signed Words with Dword Accumulation and Saturation (4-iterations)</summary>
        VP4DPWSSDS 

		VPERMB
		VPERMI2B
		VPERMT2B

		VPMADD52HUQ
		VPMADD52LUQ

		VPMULTISHIFTQB

		VPOPCNTD 
		VPOPCNTQ

		#endregion